@@ -128,8 +128,8 @@ func TestMergeUserSystemNoProxy(t *testing.T) {
 				cluster: cfgMapWithInstallConfig(cfgMapKey, cfgMapData),
 			},
 			want: ".cluster.local,.svc,10.0.0.0/16,10.128.0.0/14,127.0.0.1,169.254.169.254,172.30.0.0/16," +
-				"api-int.test.cluster.com,etcd-0.test.cluster.com,etcd-1.test.cluster.com," +
-				"etcd-2.test.cluster.com,localhost,metadata,metadata.google.internal,metadata.google.internal.",
+				"api-int.test.cluster.com,etcd-0.test.cluster.com,etcd-1.test.cluster.com,etcd-2.test.cluster.com," +
+				"localhost,metadata,metadata.google.internal,metadata.google.internal.",
 			wantErr: false,
 		},
 		{name: "valid proxy config using us-east-1 aws region",
